@@ -1,14 +1,17 @@
 import logging
 import time
+from pathlib import Path
+
 from typing import List, Optional, Tuple, Union
 
 import aiohttp
 import discord
 import lavalink
-from discord.embeds import EmptyEmbed
-from redbot.core.utils import AsyncIter
 
+from discord.embeds import EmptyEmbed
 from redbot.core import commands
+from redbot.core.i18n import Translator
+from redbot.core.utils import AsyncIter
 from redbot.core.utils.chat_formatting import bold, escape
 
 from ...audio_dataclasses import _PARTIALLY_SUPPORTED_MUSIC_EXT, Query
@@ -16,9 +19,10 @@ from ...audio_logging import IS_DEBUG, debug_exc_log
 from ...errors import QueryUnauthorized, SpotifyFetchError, TrackEnqueueError
 from ...utils import Notifier
 from ..abc import MixinMeta
-from ..cog_utils import CompositeMetaClass, _
+from ..cog_utils import CompositeMetaClass
 
 log = logging.getLogger("red.cogs.Audio.cog.Utilities.player")
+_ = Translator("Audio", Path(__file__))
 
 
 class PlayerUtilities(MixinMeta, metaclass=CompositeMetaClass):
@@ -42,7 +46,7 @@ class PlayerUtilities(MixinMeta, metaclass=CompositeMetaClass):
         self._error_timer[guild] = now
         return self._error_counter[guild] >= 5
 
-    def get_active_player_count(self) -> Tuple[Optional[str], int]:
+    async def get_active_player_count(self) -> Tuple[Optional[str], int]:
         try:
             current = next(
                 (
@@ -52,7 +56,7 @@ class PlayerUtilities(MixinMeta, metaclass=CompositeMetaClass):
                 ),
                 None,
             )
-            get_single_title = self.get_track_description_unformatted(
+            get_single_title = await self.get_track_description_unformatted(
                 current, self.local_folder_current_path
             )
             playing_servers = len(lavalink.active_players())
@@ -149,7 +153,7 @@ class PlayerUtilities(MixinMeta, metaclass=CompositeMetaClass):
         elif autoplay and not player.queue:
             embed = discord.Embed(
                 title=_("Track Skipped"),
-                description=self.get_track_description(
+                description=await self.get_track_description(
                     player.current, self.local_folder_current_path
                 ),
             )
@@ -184,7 +188,7 @@ class PlayerUtilities(MixinMeta, metaclass=CompositeMetaClass):
         else:
             embed = discord.Embed(
                 title=_("Track Skipped"),
-                description=self.get_track_description(
+                description=await self.get_track_description(
                     player.current, self.local_folder_current_path
                 ),
             )
@@ -208,6 +212,17 @@ class PlayerUtilities(MixinMeta, metaclass=CompositeMetaClass):
         except (IndexError, KeyError):
             return False
 
+    async def self_deafen(self, player: lavalink.Player) -> None:
+        guild_id = self.rgetattr(player, "channel.guild.id", None)
+        if not guild_id:
+            return
+        if not await self.config.guild_from_id(guild_id).auto_deafen():
+            return
+        channel_id = player.channel.id
+        node = player.manager.node
+        voice_ws = node.get_voice_ws(guild_id)
+        await voice_ws.voice_state(guild_id, channel_id, self_deaf=True)
+
     async def _get_spotify_tracks(
         self, ctx: commands.Context, query: Query, forced: bool = False
     ) -> Union[discord.Message, List[lavalink.Track], lavalink.Track]:
@@ -267,6 +282,9 @@ class PlayerUtilities(MixinMeta, metaclass=CompositeMetaClass):
                 return await self.send_embed_msg(
                     ctx, title=error.message.format(prefix=ctx.prefix)
                 )
+            except Exception as e:
+                self.update_player_lock(ctx, False)
+                raise e
             self.update_player_lock(ctx, False)
             try:
                 if enqueue_tracks:
@@ -285,7 +303,7 @@ class PlayerUtilities(MixinMeta, metaclass=CompositeMetaClass):
                             ctx,
                             title=_("Unable to Get Track"),
                             description=_(
-                                "I'm unable get a track from Lavalink at the moment, "
+                                "I'm unable to get a track from Lavalink at the moment, "
                                 "try again in a few minutes."
                             ),
                         )
@@ -315,16 +333,21 @@ class PlayerUtilities(MixinMeta, metaclass=CompositeMetaClass):
                         "\nUse `{prefix}audioset spotifyapi` for instructions."
                     ).format(prefix=ctx.prefix),
                 )
+            except Exception as e:
+                self.update_player_lock(ctx, False)
+                raise e
         elif query.is_album or query.is_playlist:
-            self.update_player_lock(ctx, True)
-            track_list = await self.fetch_spotify_playlist(
-                ctx,
-                "album" if query.is_album else "playlist",
-                query,
-                enqueue_tracks,
-                forced=forced,
-            )
-            self.update_player_lock(ctx, False)
+            try:
+                self.update_player_lock(ctx, True)
+                track_list = await self.fetch_spotify_playlist(
+                    ctx,
+                    "album" if query.is_album else "playlist",
+                    query,
+                    enqueue_tracks,
+                    forced=forced,
+                )
+            finally:
+                self.update_player_lock(ctx, False)
             return track_list
         else:
             return await self.send_embed_msg(
@@ -354,9 +377,7 @@ class PlayerUtilities(MixinMeta, metaclass=CompositeMetaClass):
         playlist_url = None
         seek = 0
         if type(query) is not list:
-            if not await self.is_query_allowed(
-                self.config, ctx.guild, f"{query}", query_obj=query
-            ):
+            if not await self.is_query_allowed(self.config, ctx, f"{query}", query_obj=query):
                 raise QueryUnauthorized(
                     _("{query} is not an allowed query.").format(query=query.to_string_user())
                 )
@@ -373,10 +394,13 @@ class PlayerUtilities(MixinMeta, metaclass=CompositeMetaClass):
                     ctx,
                     title=_("Unable to Get Track"),
                     description=_(
-                        "I'm unable get a track from Lavalink at the moment, "
+                        "I'm unable to get a track from Lavalink at the moment, "
                         "try again in a few minutes."
                     ),
                 )
+            except Exception as e:
+                self.update_player_lock(ctx, False)
+                raise e
             tracks = result.tracks
             playlist_data = result.playlist_info
             if not enqueue:
@@ -423,13 +447,12 @@ class PlayerUtilities(MixinMeta, metaclass=CompositeMetaClass):
             async for track in AsyncIter(tracks):
                 if len(player.queue) >= 10000:
                     continue
+                query = Query.process_input(track, self.local_folder_current_path)
                 if not await self.is_query_allowed(
                     self.config,
-                    ctx.guild,
-                    (
-                        f"{track.title} {track.author} {track.uri} "
-                        f"{str(Query.process_input(track, self.local_folder_current_path))}"
-                    ),
+                    ctx,
+                    f"{track.title} {track.author} {track.uri} " f"{str(query)}",
+                    query_obj=query,
                 ):
                     if IS_DEBUG:
                         log.debug(f"Query is not allowed in {ctx.guild} ({ctx.guild.id})")
@@ -437,6 +460,13 @@ class PlayerUtilities(MixinMeta, metaclass=CompositeMetaClass):
                 elif guild_data["maxlength"] > 0:
                     if self.is_track_length_allowed(track, guild_data["maxlength"]):
                         track_len += 1
+                        track.extras.update(
+                            {
+                                "enqueue_time": int(time.time()),
+                                "vc": player.channel.id,
+                                "requester": ctx.author.id,
+                            }
+                        )
                         player.add(ctx.author, track)
                         self.bot.dispatch(
                             "red_audio_track_enqueue", player.channel.guild, track, ctx.author
@@ -444,6 +474,13 @@ class PlayerUtilities(MixinMeta, metaclass=CompositeMetaClass):
 
                 else:
                     track_len += 1
+                    track.extras.update(
+                        {
+                            "enqueue_time": int(time.time()),
+                            "vc": player.channel.id,
+                            "requester": ctx.author.id,
+                        }
+                    )
                     player.add(ctx.author, track)
                     self.bot.dispatch(
                         "red_audio_track_enqueue", player.channel.guild, track, ctx.author
@@ -499,13 +536,15 @@ class PlayerUtilities(MixinMeta, metaclass=CompositeMetaClass):
                 )
                 if seek and seek > 0:
                     single_track.start_timestamp = seek * 1000
+                query = Query.process_input(single_track, self.local_folder_current_path)
                 if not await self.is_query_allowed(
                     self.config,
-                    ctx.guild,
+                    ctx,
                     (
                         f"{single_track.title} {single_track.author} {single_track.uri} "
-                        f"{str(Query.process_input(single_track, self.local_folder_current_path))}"
+                        f"{str(query)}"
                     ),
+                    query_obj=query,
                 ):
                     if IS_DEBUG:
                         log.debug(f"Query is not allowed in {ctx.guild} ({ctx.guild.id})")
@@ -515,6 +554,13 @@ class PlayerUtilities(MixinMeta, metaclass=CompositeMetaClass):
                     )
                 elif guild_data["maxlength"] > 0:
                     if self.is_track_length_allowed(single_track, guild_data["maxlength"]):
+                        single_track.extras.update(
+                            {
+                                "enqueue_time": int(time.time()),
+                                "vc": player.channel.id,
+                                "requester": ctx.author.id,
+                            }
+                        )
                         player.add(ctx.author, single_track)
                         player.maybe_shuffle()
                         self.bot.dispatch(
@@ -530,6 +576,13 @@ class PlayerUtilities(MixinMeta, metaclass=CompositeMetaClass):
                         )
 
                 else:
+                    single_track.extras.update(
+                        {
+                            "enqueue_time": int(time.time()),
+                            "vc": player.channel.id,
+                            "requester": ctx.author.id,
+                        }
+                    )
                     player.add(ctx.author, single_track)
                     player.maybe_shuffle()
                     self.bot.dispatch(
@@ -542,7 +595,12 @@ class PlayerUtilities(MixinMeta, metaclass=CompositeMetaClass):
                 if await self.bot.is_owner(ctx.author):
                     desc = _("Please check your console or logs for details.")
                 return await self.send_embed_msg(ctx, title=title, description=desc)
-            description = self.get_track_description(single_track, self.local_folder_current_path)
+            except Exception as e:
+                self.update_player_lock(ctx, False)
+                raise e
+            description = await self.get_track_description(
+                single_track, self.local_folder_current_path
+            )
             embed = discord.Embed(title=_("Track Enqueued"), description=description)
             if not guild_data["shuffle"] and queue_dur > 0:
                 embed.set_footer(
@@ -588,6 +646,7 @@ class PlayerUtilities(MixinMeta, metaclass=CompositeMetaClass):
                 lock=self.update_player_lock,
                 notifier=notifier,
                 forced=forced,
+                query_global=await self.config.global_db_enabled(),
             )
         except SpotifyFetchError as error:
             self.update_player_lock(ctx, False)
@@ -602,7 +661,7 @@ class PlayerUtilities(MixinMeta, metaclass=CompositeMetaClass):
                 ctx,
                 title=_("Unable to Get Track"),
                 description=_(
-                    "I'm unable get a track from Lavalink at the moment,"
+                    "I'm unable to get a track from Lavalink at the moment, "
                     "try again in a few minutes."
                 ),
                 error=True,
@@ -617,7 +676,8 @@ class PlayerUtilities(MixinMeta, metaclass=CompositeMetaClass):
         except Exception as e:
             self.update_player_lock(ctx, False)
             raise e
-        self.update_player_lock(ctx, False)
+        finally:
+            self.update_player_lock(ctx, False)
         return track_list
 
     async def set_player_settings(self, ctx: commands.Context) -> None:
@@ -657,6 +717,7 @@ class PlayerUtilities(MixinMeta, metaclass=CompositeMetaClass):
                 and len(player.queue) == 0
             ):
                 await player.move_to(user_channel)
+                await self.self_deafen(player)
                 return True
         else:
             return False
