@@ -29,6 +29,7 @@ from typing import (
     overload,
 )
 from types import MappingProxyType
+from rich.console import Console
 
 import discord
 from discord.ext import commands as dpy_commands
@@ -161,6 +162,7 @@ class RedBase(
         self._ignored_cache = IgnoreManager(self._config)
         self._whiteblacklist_cache = WhitelistBlacklistManager(self._config)
         self._i18n_cache = I18nManager(self._config)
+        self._bypass_cooldowns = False
 
         async def prefix_manager(bot, message) -> List[str]:
             prefixes = await self._prefix_cache.get_prefixes(message.guild)
@@ -221,6 +223,9 @@ class RedBase(
 
         self._deletion_requests: MutableMapping[int, asyncio.Lock] = weakref.WeakValueDictionary()
 
+        # Although I see the use of keeping this public, lets rather make it private.
+        self._rich_console = Console()
+
     def set_help_formatter(self, formatter: commands.help.HelpFormatterABC):
         """
         Set's Red's help formatter.
@@ -878,7 +883,7 @@ class RedBase(
                 packages.insert(0, "permissions")
 
             to_remove = []
-            print("Loading packages...")
+            log.info("Loading packages...")
             for package in packages:
                 try:
                     spec = await self._cog_mgr.find_cog(package)
@@ -901,7 +906,7 @@ class RedBase(
             for package in to_remove:
                 packages.remove(package)
             if packages:
-                print("Loaded packages: " + ", ".join(packages))
+                log.info("Loaded packages: " + ", ".join(packages))
 
         if self.rpc_enabled:
             await self.rpc.initialize(self.rpc_port)
@@ -1374,14 +1379,15 @@ class RedBase(
                 if permissions_not_loaded:
                     subcommand.requires.ready_event.set()
 
-    def remove_command(self, name: str) -> None:
+    def remove_command(self, name: str) -> Optional[commands.Command]:
         command = super().remove_command(name)
-        if not command:
-            return
+        if command is None:
+            return None
         command.requires.reset()
         if isinstance(command, commands.Group):
             for subcommand in command.walk_commands():
                 subcommand.requires.reset()
+        return command
 
     def clear_permission_rules(self, guild_id: Optional[int], **kwargs) -> None:
         """Clear all permission overrides in a scope.
